---
hide_toc: true
...

# Project Information

This website was generated with the Elstir static site generator, a fork of [MkDocs](https://Mkdocs.org) which uses [Pandoc](https://Pandoc.org) as the backend. The theme uses [Bootstrap]() and is heavily adapted from [Bootswatch](https://bootswatch.com/). Additional sources of inspiration for the layout of this site include [Numba](http://numba.pydata.org/), [Pandas](), and [Codecov](https://about.codecov.io/).

This website and corresponding project is in a very early stage of development and has not yet been licensed. The content of this website (including without limitation the text, computer code, artwork, photographs, images, audio material, video material and audio-visual material on this website) is owned by the author.

For the time being, any redistribution or reproduction of part or all of the contents in any form is prohibited other than the following:

- You may view this website and the material on this website on a computer or mobile device via a web browser;
- You may copy and store this website and the material on this website in your web browser cache memory;
- You may print pages from this website for your own use.

You may not distribute or commercially exploit the content. Nor may you transmit it or store it in any other website or other form of electronic retrieval system. The automated and/or systematic collection of data from this website is prohibited.

## License

This project is not yet licensed.

## Disclaimer


THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

